@@ -5,7 +5,7 @@ const assert = require('assert')
 const suite = new helper.Suite()
 
 const testPoolSize = function (max) {
-  suite.testAsync(`test ${max} queries executed on a pool rapidly`, () => {
+  suite.testAsync(`test ${max} queries executed on a pool rapidly`, async () => {
     const pool = new helper.pg.Pool({ max: 10 })
 
     let count = 0
