@@ -112,10 +112,6 @@ test('executing query', function () {
         text: 'INSERT 31 1',
       })
     })
-
-    test('removes itself after another readyForQuery message', function () {
-      return false
-    })
   })
 
   test('handles errors', function () {
